@@ -33,7 +33,9 @@
 #include <QTimer>
 #include <QToolTip>
 
+#ifndef Q_OS_WIN
 #include <KX11Extras>
+#endif
 
 #include <cmath>
 
@@ -47,7 +49,9 @@ DropTarget::DropTarget(MainWindow *mw)
     , animTimer(nullptr)
     , showInformation(false)
 {
+#ifndef Q_OS_WIN
     KX11Extras::setState(winId(), NET::SkipTaskbar | NET::KeepAbove);
+#endif
 
     auto screen = qApp->screenAt(Settings::dropPosition());
     if (screen) {
@@ -90,7 +94,7 @@ DropTarget::DropTarget(MainWindow *mw)
     auto *quitAction = new QAction(this);
     quitAction->setText(i18n("Quit KGet"));
     quitAction->setIcon(QIcon::fromTheme("system-shutdown"));
-    connect(quitAction, SIGNAL(triggered()), mw, SLOT(slotQuit()));
+    connect(quitAction, &QAction::triggered, mw, &MainWindow::slotQuit);
     popupMenu->addAction(quitAction);
 
     isdragging = false;
